Learning to Use Dallinger
=========================

Beginner
~~~~~~~~

Key concepts in Dallinger
'''''''''''''''''''''''''

-  :doc:`classes`
-  :doc:`the_experiment_class`

Dallinger as a web app
''''''''''''''''''''''

-  :doc:`communicating_with_the_server`
-  :doc:`web_api`

Experimental design
'''''''''''''''''''

-  :doc:`required_experimental_files`
-  config.txt
-  Dallinger.js

Example walkthroughs
''''''''''''''''''''

-  Bartlett1932 walkthrough

Intermediate
~~~~~~~~~~~~

Experimental design
'''''''''''''''''''

-  Networks
-  Nodes
-  Infos
-  Transformations
-  Using properties 1 through 5
-  Processes
-  Failing
-  :doc:`waiting_rooms`

Running experiments
'''''''''''''''''''

-  :doc:`command_line_utility`
-  Debugging

Advanced
~~~~~~~~

Experimental design
'''''''''''''''''''

-  Changing route behavior and making new routes
-  Sending requests from within Dallinger

Running experiments
'''''''''''''''''''

-  Writing automated tests
-  Compensating workers
-  Monitoring a live experiment
-  Recruiters
